@@ -1,5 +1,6 @@
 import numpy as np
 import re
+from fast_project import _projectRects
 
 
 def enum(**enums): return type('Enum', (), enums)
@@ -8,14 +9,15 @@ ShapeCodes = enum(POINT=0, LINE=1, RECT=2)
 
 
 class Glyphset(object):
-    """shaper + shape-params + associated data ==> Glyphset
+    """
+    shaper + shape-params + associated data ==> Glyphset
+    This reference implementation uses numpy arrays for the backing store.
 
-       fields:
+    fields:
        _points : Points held by this glyphset
        _data : Data associated with the points (basis for 'info' values).
-               _points[x] should associate with data[x]
        shapecode: Shapecode that tells how to interpret _points
-
+       Note: _points[x] should associate with data[x]
     """
     _points = None
     _data = None
@@ -45,6 +47,27 @@ class Glyphset(object):
             # TODO: Setup the shaper utilities to go directly to fortran order
             return np.array(self.shaper(self._points), order="F")
 
+    def project(self, viewxform):
+        """Project the points found in the glyphset according to the view transform.
+
+        viewxform -- convert canvas space to pixel space [tx,ty,sx,sy]
+        returns a new glyphset with projected points and associated info values
+        """
+        points = self.points()
+        out = np.empty_like(points, dtype=np.int32)
+        _projectRects(viewxform, points, out)
+
+        # Ensure visilibity, make sure w/h are always at least one
+        # TODO: There is probably a more numpy-ish way to do this...
+        for i in xrange(0, out.shape[0]):
+            if out[i, 0] == out[i, 2]:
+                out[i, 2] += 1
+            if out[i, 1] == out[i, 3]:
+                out[i, 3] += 1
+
+        return Glyphset(out, self.data(), Literals(self.shaper.code))
+
+
     def data(self):
         return self._data
 
@@ -150,17 +173,24 @@ def const(v):
     return f
 
 
-def idx(i):
+def item(i):
     """
-    Create a function that expects an indexable thing
-    and returns a value at the passed index
+    Get items out of a collection.  
+    Suiteable for use with numerically indexed (i.e., array)
+    or object-indexed (i.e., dictionary) sources.
 
-    * i -- The index that will be used
+    * i -- The item parameter that will be used
+    
+    TODO: Change method name to 'item'
     """
     def f(a):
         return a[i]
     return f
 
+def idx(i):
+    "The same as item, but a common name when using numeric indexes"
+    return item(i)
+
 
 def load_csv(filename, skip, xc, yc, vc, width, height, shapecode):
     """Turn a csv file into a glyphset.
@@ -191,3 +221,30 @@ def load_csv(filename, skip, xc, yc, vc, width, height, shapecode):
 
     source.close()
     return Glyphset(glyphs, data, Literals(shapecode))
+
+
+def load_hdf(filename, node, xc, yc, vc, width, height, shapecode):
+    """
+    Load a node from an HDF file.
+
+    filename : HDF file to load
+    node: Path to relevant HDF table
+    xc: Name/index of the x column
+    yc: Name/index of the y column
+    vc: Name/index of the value column (if applicable)
+    cats: List of expected categories. 
+        If cats is an empty list, a coding will be automatically generated
+        Any value not on the list will be assigned category equal to list lenght
+        Ignored if vc is not supplied.
+    """
+    import pandas as pd
+    table = pd.read_hdf(filename, node)
+    x = np.array(table[xc])
+    y = np.array(table[yc])
+    w = np.array([width] * len(x))
+    h = np.array([height] * len(x))
+    points = np.vstack([x,y,w,h]).T
+    data = table[vc] if vc else ([1] * len(x))
+    print("Loaded %d items" % len(x))
+
+    return Glyphset(points, data, Literals(shapecode))
