@@ -1,35 +1,38 @@
 import core
+import util
 import numpy as np
 import math
 
 
 # ----------- Aggregators -----------
-class Count(core.Aggregator):
+class Count(core.GlyphAggregator):
     """Count the number of items that fall into a particular grid element."""
     out_type = np.int32
     identity = 0
 
-    def allocate(self, width, height, glyphset, infos):
+    def allocate(self, glyphset, screen):
+        (width, height) = screen
         return np.zeros((height, width), dtype=self.out_type)
 
     def combine(self, existing, glyph, shapecode, val):
-        update = core.glyphAggregates(glyph, shapecode, 1, self.identity)
+        update = self.glyphAggregates(glyph, shapecode, 1, self.identity)
         existing[glyph[1]:glyph[3], glyph[0]:glyph[2]] += update
 
     def rollup(self, *vals):
         return reduce(lambda x, y: x+y,  vals)
 
 
-class Sum(core.Aggregator):
+class Sum(core.GlyphAggregator):
     """Count the number of items that fall into a particular grid element."""
     out_type = np.int32
     identity = 0
 
-    def allocate(self, width, height, glyphset, infos):
+    def allocate(self, glyphset, screen):
+        (width, height) = screen
         return np.zeros((height, width), dtype=self.out_type)
 
     def combine(self, existing, glyph, shapecode, val):
-        update = core.glyphAggregates(glyph, shapecode, val, self.identity)
+        update = self.glyphAggregates(glyph, shapecode, val, self.identity)
         existing[glyph[1]:glyph[3], glyph[0]:glyph[2]] += update
 
     def rollup(self, *vals):
@@ -117,9 +120,9 @@ class Spread(core.SequentialShader):
 
     def cellfunc(self, grid, x, y):
         (height, width) = grid.shape
-        minx = max(0, x-self.left-self.right) 
+        minx = max(0, x-self.left-self.right)
         maxx = min(x+1, width)
-        miny = max(0, y-self.up-self.down) 
+        miny = max(0, y-self.up-self.down)
         maxy = min(y+1, height)
 
         parts = grid[miny:maxy, minx:maxx]
@@ -170,7 +173,7 @@ class InterpolateColors(core.CellShader):
     def __init__(self,
                  low, high,
                  log=False,
-                 reserve=core.Color(255, 255, 255, 255),
+                 reserve=util.Color(255, 255, 255, 255),
                  empty=np.nan):
         self.low = low
         self.high = high
